all.Enfms<-function(){
     cat("\n")
     note_for_Enfss_input()
     cat("\n")
     note_for_close_window()
     EnfMSpar<-data.frame(subject=c(1,2),Gender=c(0),bw=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     EnfMSpar<-edit(EnfMSpar)
##     EnfMSpar<-ymscheck(EnfMSpar)
     cat("\n")
     Enf.ms(length(EnfMSpar$subject),EnfMSpar$c,EnfMSpar$tau,EnfMSpar$ts,EnfMSpar$D,EnfMSpar$bw,EnfMSpar$Gender)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Enfss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-pocpr(samplesStats("ka"),EnfMSpar$D,EnfMSpar$tau,EnfMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-pocpr(samplesStats("ka"),EnfMSpar$D,EnfMSpar$tau,EnfMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}